@@ -2,7 +2,7 @@
  *            verve-plugin.c
  *
  *  Copyright © 2006-2007 Jannis Pohlmann <jannis@xfce.org>
- *  Copyright © 2015 Isaac Schemm <isaacschemm@gmail.com>
+ *  Copyright © 2015-2018 Isaac Schemm <isaacschemm@gmail.com>
  ****************************************************************************/
 
 /*
@@ -33,7 +33,7 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/libxfce4panel.h>
 #include <libxfce4ui/libxfce4ui.h>
 
 #include "verve.h"
@@ -88,7 +88,7 @@ typedef struct
 G_LOCK_DEFINE_STATIC (plugin_completion_mutex);
 
 
-void
+static void
 verve_plugin_load_completion (VerveEnv* env, gpointer user_data)
 {
   VervePlugin *verve = (VervePlugin*) user_data;
@@ -125,12 +125,12 @@ verve_plugin_load_completion (VerveEnv* env, gpointer user_data)
 
   
 static gboolean
-verve_plugin_focus_timeout (VervePlugin *verve)
+verve_plugin_focus_timeout (gpointer user_data)
 {
+  VervePlugin *verve = user_data;
   GtkStyle *style;
   GdkColor c;
   
-  g_return_val_if_fail (verve != NULL, FALSE);
   g_return_val_if_fail (verve->input != NULL || GTK_IS_ENTRY (verve->input), FALSE);
   
   /* Determine current entry style */
@@ -225,7 +225,7 @@ verve_plugin_grab_focus (VerveDBusService *dbus_service,
       
       /* Make it flashy so chances are higher that the user notices the focus */
       if (verve->focus_timeout == 0) 
-        verve->focus_timeout = g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE, 250, (GSourceFunc)verve_plugin_focus_timeout, verve, NULL);
+        verve->focus_timeout = g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE, 250, verve_plugin_focus_timeout, verve, NULL);
     }
 }
 #endif
@@ -542,7 +542,7 @@ verve_plugin_new (XfcePanelPlugin *plugin)
 
   /* Set up a CSS provider for the entry */
   verve->input_css = gtk_css_provider_new ();
-  gtk_style_context_add_provider (gtk_widget_get_style_context (verve->input), verve->input_css, GTK_STYLE_PROVIDER_PRIORITY_SETTINGS);
+  gtk_style_context_add_provider (gtk_widget_get_style_context (verve->input), GTK_STYLE_PROVIDER(verve->input_css), GTK_STYLE_PROVIDER_PRIORITY_SETTINGS);
 
   /* Handle mouse button and key press events */
   g_signal_connect (verve->input, "key-press-event", G_CALLBACK (verve_plugin_keypress_cb), verve);
@@ -626,7 +626,7 @@ verve_plugin_update_label (XfcePanelPlugin *plugin,
   g_return_val_if_fail (verve != NULL, FALSE);
 
   /* Set text in internal label object */
-  gtk_label_set_text(verve->label, label);
+  gtk_label_set_text(GTK_LABEL(verve->label), label);
 
   return TRUE;
 }
@@ -656,7 +656,8 @@ verve_plugin_update_colors (XfcePanelPlugin *plugin,
 
   GFileIOStream *tmp_file_stream;
   GFile *tmp_file = g_file_new_tmp (NULL, &tmp_file_stream, NULL);
-  GOutputStream *output_stream = g_io_stream_get_output_stream (tmp_file_stream);
+  GIOStream *iostream = G_IO_STREAM (tmp_file_stream);
+  GOutputStream *output_stream = g_io_stream_get_output_stream (iostream);
 
   // Write CSS to temporary file
   write_string (output_stream, "*{color:", "");
@@ -683,7 +684,7 @@ verve_plugin_update_colors (XfcePanelPlugin *plugin,
   write_string (output_stream, verve->base_color_str, "unset");
   write_string (output_stream, "}", "");
 
-  g_io_stream_close (tmp_file_stream, NULL, NULL);
+  g_io_stream_close (iostream, NULL, NULL);
 
   gtk_css_provider_load_from_file (verve->input_css, tmp_file, NULL);
   g_file_delete (tmp_file, NULL, NULL);
@@ -740,12 +741,12 @@ verve_plugin_read_rc_file (XfcePanelPlugin *plugin,
   gint    size = 20;
 
   /* Default label */
-  gchar  *label = "";
+  const gchar  *label = "";
   
   /* Default foreground and background colors */
-  gchar  *fg_color_str = "";
-  gchar  *bg_color_str = "";
-  gchar  *base_color_str = "";
+  const gchar *fg_color_str = "";
+  const gchar *bg_color_str = "";
+  const gchar *base_color_str = "";
 
   /* Default number of saved history entries */
   gint    history_length = 25;
@@ -761,7 +762,7 @@ verve_plugin_read_rc_file (XfcePanelPlugin *plugin,
   verve->launch_params.use_shell = TRUE;
 
   /* Default search engine URL */
-  gchar *smartbookmark_url = "";
+  const gchar *smartbookmark_url = "";
 
   g_return_if_fail (plugin != NULL);
   g_return_if_fail (verve != NULL);
@@ -857,7 +858,7 @@ verve_plugin_write_rc_file (XfcePanelPlugin *plugin,
       xfce_rc_write_int_entry (rc, "size", verve->size);
 
       /* Write label value */
-      xfce_rc_write_entry (rc, "label", gtk_label_get_text(verve->label));
+      xfce_rc_write_entry (rc, "label", gtk_label_get_text(GTK_LABEL(verve->label)));
 
       /* Write number of saved history entries */
       xfce_rc_write_int_entry (rc, "history-length", verve->history_length);
@@ -903,29 +904,37 @@ verve_plugin_size_changed (GtkSpinButton *spin,
 
 
 static void
-verve_plugin_fg_color_changed (GtkEntry *box, 
+verve_plugin_fg_color_changed (GtkColorButton *color_button, 
                                VervePlugin *verve)
 {
   g_return_if_fail (verve != NULL);
 
   /* Get the entered color */
-  const gchar *color_str = gtk_entry_get_text (box);
+  GdkRGBA color;
+  gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER(color_button), &color);
+  gchar *color_str = gdk_rgba_to_string (&color);
 
   verve_plugin_update_colors (NULL, color_str, NULL, NULL, verve);
+
+  g_free (color_str);
 }
 
 
 
 static void
-verve_plugin_base_color_changed (GtkEntry *box, 
+verve_plugin_base_color_changed (GtkColorButton *color_button, 
                                  VervePlugin *verve)
 {
   g_return_if_fail (verve != NULL);
 
   /* Get the entered color */
-  const gchar *color_str = gtk_entry_get_text (box);
+  GdkRGBA color;
+  gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER(color_button), &color);
+  gchar *color_str = gdk_rgba_to_string (&color);
 
   verve_plugin_update_colors (NULL, NULL, NULL, color_str, verve);
+
+  g_free (color_str);
 }
 
 
@@ -1099,7 +1108,7 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   GtkWidget *label_box;
   GtkWidget *history_length_label;
   GtkWidget *history_length_spin;
-  GObject *adjustment;
+  GtkAdjustment *adjustment;
 
   GtkWidget *bin3;
   GtkWidget *alignment;
@@ -1233,18 +1242,20 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   gtk_widget_show (base_color_label);
 
   /* Plugin background color entry field */
-  base_color_box = gtk_entry_new();
+  base_color_box = gtk_color_button_new();
 
   /* Set text to current background color */
   if (verve->base_color_str) {
-    gtk_entry_set_text(GTK_ENTRY (base_color_box), verve->base_color_str);
+    GdkRGBA color;
+    gdk_rgba_parse(&color, verve->base_color_str);
+    gtk_color_button_set_rgba(GTK_COLOR_BUTTON (base_color_box), &color);
   }
   gtk_widget_add_mnemonic_label (base_color_box, base_color_label);
   gtk_box_pack_start (GTK_BOX (hbox), base_color_box, FALSE, TRUE, 0);
   gtk_widget_show (base_color_box);
 
   /* Be notified when the user requests a different background color setting */
-  g_signal_connect (base_color_box, "changed", G_CALLBACK (verve_plugin_base_color_changed), verve);
+  g_signal_connect (base_color_box, "color-set", G_CALLBACK (verve_plugin_base_color_changed), verve);
 
   /* Plugin foreground color container */
   hbox = gtk_hbox_new (FALSE, 8);
@@ -1252,23 +1263,25 @@ verve_plugin_properties (XfcePanelPlugin *plugin,
   gtk_widget_show (hbox);
 
   /* Plugin foreground color label */
-  fg_color_label = gtk_label_new (_("Foreground color:"));
+  fg_color_label = gtk_label_new (_("Text color:"));
   gtk_box_pack_start (GTK_BOX (hbox), fg_color_label, FALSE, TRUE, 0);
   gtk_widget_show (fg_color_label);
 
   /* Plugin foreground color entry field */
-  fg_color_box = gtk_entry_new();
+  fg_color_box = gtk_color_button_new();
 
-  /* Set text to current foreground color */
+  /* Set color to current foreground color */
   if (verve->fg_color_str) {
-    gtk_entry_set_text(GTK_ENTRY (fg_color_box), verve->fg_color_str);
+    GdkRGBA color;
+    gdk_rgba_parse(&color, verve->fg_color_str);
+    gtk_color_button_set_rgba(GTK_COLOR_BUTTON (fg_color_box), &color);
   }
   gtk_widget_add_mnemonic_label (fg_color_box, fg_color_label);
   gtk_box_pack_start (GTK_BOX (hbox), fg_color_box, FALSE, TRUE, 0);
   gtk_widget_show (fg_color_box);
 
   /* Be notified when the user requests a different foreground color setting */
-  g_signal_connect (fg_color_box, "changed", G_CALLBACK (verve_plugin_fg_color_changed), verve);
+  g_signal_connect (fg_color_box, "color-set", G_CALLBACK (verve_plugin_fg_color_changed), verve);
 
   /* Frame for behaviour settings */
   frame = xfce_gtk_frame_box_new (_("History"), &bin2);
